pub enum Token {
KeywordExtern,
KeywordWithLevel,
KeywordPrivilege(Ring),
KeywordIsr,
KeywordCall,
Identifier(String),
LeftParen,
RightParen,
LeftBracket,
RightBracket,
Comma,
Dollar,
}Expand description
The fundamental unit of a source code file. These are used to represent the lexemes within a source file
Variants
KeywordExtern
KeywordWithLevel
KeywordPrivilege(Ring)
KeywordIsr
KeywordCall
Identifier(String)
LeftParen
RightParen
LeftBracket
RightBracket
Comma
Dollar
‘$’ is a special Anillo token only allowed within an ISR. It directly refers to the number of the ISR itself.