pub struct FuncArg {
_name: String,
type_t: FuncArgType,
}Fields
_name: StringTODO(SEP): Do something with the func arg name when we have arbitrary arg usage
type_t: FuncArgTypetype is likely reserved by the rust language for use so I can’t use the darn name
Implementations