TokenInfo

Struct TokenInfo 

pub struct TokenInfo {
    token: Token,
    line: u32,
    col: u32,
}
A small wrapper around a Token that also contains line and column info. This just lets the lexer and parser output meaningful error messages so a user knows where a mistake may have been made.

Fields

token: Tokenline: u32col: u32

Implementations

Source

impl TokenInfo

pub fn new(token: Token, line: u32, col: u32) -> TokenInfo

pub fn borrow_token(&self) -> &Token

Simply used to directly pattern match on the internal token field.

pub fn line(&self) -> u32

pub fn col(&self) -> u32