pub struct TokenInfo {
token: Token,
line: u32,
col: u32,
}Expand description
A small wrapper around a Token that also contains line and column info.
This just lets the lexer and parser output meaningful error messages so
a user knows where a mistake may have been made.
Fields
token: Tokenline: u32col: u32Implementations